<?php
// $Id$

/**
 * @file
 *   Definition of the 'color' panel style.
 */


/**
 * Implementation of hook_panels_default_panels_styles().
 *
 * This just provides the name and implementation of the style.
 *
 * It must be named:
 * <modulename>_<stylename>_panels_styles()
 *
 * and <stylename> must be the same as the base of this filename.
 * Since this is the 'colors' style, this file is colors.inc and the function is
 * panels_plugin_example_colors_panels_styles()
 *
 * This is the only function in the plugin that has a magic name. All
 * others are free-form names, but you should use good namespacing.
 */
function panels_plugin_example_colors_example_panels_styles() {
  return array(
    'title' => t('Example: Color text style'),
    'description' => t('Simply changes the text color of a pane, as an example.'),

    // Names the function we'll use to render an individual pane.
    // Add 'theme_' to the front of this for the function.
    // The actual name is freeform, just use it for namespacing.
    // Remember to rebuild the theme registry when you change this.
    'render pane' => 'panels_plugin_example_colors_style_pane',

    // Names the function to render a panel or region. This is optional.
    'render panel' => 'panels_plugin_example_colors_style_panel',

    // Names the function providing settings form for the pane. (optional)
    'pane settings form' => 'panels_plugin_example_colors_panel_config_form',

    // Names the function providing settings form for the panel. (optional)
    'settings form' => 'panels_plugin_example_colors_panel_config_form',
  );
}

/**
 * Settings form for the pane.
 *
 * Any form will do here. The settings will come through to the theme
 * function in $pane->style['settings'].
 *
 * @param $style_settings
 *   The $style_settings if they've already been set.
 * @return
 *   The form.
 */
function panels_plugin_example_colors_panel_config_form($style_settings) {
  $form['color'] = array(
    '#type' => 'radios',
    '#title' => t('Text color for pane'),
    '#options' => array(
      'red' => t('Red'),
      'blue' => t('Blue'),
      'green' => t('Green'),
    ),
    '#default_value' => (isset($style_settings['color'])) ? $style_settings['color'] : 'red',
    '#description' => t('Select the background color for the pane.'),
  );

  return $form;
}

/**
 * Render the pane content.
 *
 * The name of this function is referenced in hook_default_panels_styles(), and
 * it's free-form, but of course be careful to namespace it.
 * But the name is just theme_<render pane> where "<render pane>" is what you
 * put into the array above.
 *
 * This is optional, but shows how a plugin can render a pane.
 *
 * Please remember that you have to rebuild the theme registry after
 * introducing this function or changing its name.
 *
 * @param $content
 *   The content of the block to be rendered. It has a title and a content.
 * @param $pane
 * @param $display
 * @return
 *   rendered content
 */
function theme_panels_plugin_example_colors_style_pane($content, $pane, $display) {
  $style_settings = $pane->style['settings'];
  $color = $style_settings['color'];
  $output = "";
  if (!empty($content->title)) {
    $output .= "<h3>$content->title</h3>";
  }

  // For this simple example, wrap the content in a div with style.
  // We could have loaded extra css, etc.
  $output .= "<div style='color: $color;'>$content->content</div>";
  return $output;
}

/**
 * The function which will render the panel or region with this style.
 *
 * This is optional, but shows how the plugin can be used to change the
 * rendering of a panel or region.
 *
 * @param $display
 * @param $panel_id
 * @param $panes
 * @param $settings
 * @return
 *   Rendered output for the panel.
 */
function theme_panels_plugin_example_colors_style_panel($display, $panel_id, $panes, $settings) {
  $color = $settings['color'];
  $output = "<div style='color: $color;'>";

  $print_separator = FALSE;
  foreach ($panes as $pane_id => $content) {
    // Add the separator if we've already displayed a pane.
    if ($print_separator) {
      $output .= '<div class="panel-separator"></div>';
    }
    $output .= $text = panels_render_pane($content, $display->content[$pane_id], $display);

    // If we displayed a pane, this will become true; if not, it will become
    // false.
    $print_separator = (bool) $text;
  }
  $output .= "</div>";
  return $output;
}